"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const express_1 = require("express");
const _1 = require(".");
const helpers_1 = require("./helpers");
function Zemi(routes, router = (0, express_1.Router)({ mergeParams: true }), __routeDefinitions = (0, helpers_1.buildRouteDefinitions)(routes), __parentPath) {
    // Attach Route Definitions to Request Object
    router.use((request, response, next) => {
        request.routeDefinitions = __routeDefinitions;
        next();
    });
    // For each route...
    routes.forEach((route) => {
        // Build a path depending on if route has parent or not
        const path = route.path;
        const fullPath = __parentPath ? `${__parentPath}${path}` : path;
        // Add middleware specified for route
        route.middleware &&
            route.middleware.forEach((middleware) => router.use((request, response, next) => middleware(request, response, next)));
        // For each child route, call Zemi on it, so it can recursively build that route
        // and all it's children. This NEEDS to happen before the current route gets defined,
        // since child routes are more specific.
        route.routes && router.use(path, Zemi(route.routes, router, __routeDefinitions, fullPath));
        // For each Zemi HTTP method...
        const methods = Object.values(_1.ZemiMethod);
        methods.forEach((method) => {
            const handler = route[method];
            if (handler) {
                // If there's a handler defined for the method, find the route definition...
                const routeDef = Object.keys(__routeDefinitions)
                    .map((rdk) => __routeDefinitions[rdk])
                    .filter((rd) => rd.path === fullPath)[0];
                // and create a route in ExpressJS
                router[method](path, (request, response, next) => handler(request, response, next, routeDef));
            }
        });
    });
    return router;
}
exports.default = Zemi;
//# sourceMappingURL=core.js.map